// Persistence Of Vision raytracer version 3.6 sample file.
// File by Burkhard Reike
// Last updated: 2009.3.19
//
// Description:
//
// Scene File 3 of image sequence demo. It demonstrates
// - how to embed image sequences in a scene,
// - how to downsample and upsample image sequences, and
// - how to add additional blurriness.
//
// Rendered at 25 FPS, it shows:
// 1) The image sequence made with demoa.pov (60fps), with default image blending.
// 2) The image sequence made with demob.pov (8fps), with default image blending.
// 3) The image sequence made with demoa.pov (60fps), with image blending and additional blurriness.
// 4) The image sequence made with demob.pov (8fps), with image blending and additional blurriness
// 

global_settings { assumed_gamma 1.0 }

#include "shapes.inc"
#include "colors.inc" 

#include "imagesequence.inc"
    
//
// Let's define the 4 image sequences first.
//     
             
#declare I1 = IS_CreateImageSequence();
IS_SetName(I1,"demoa")
IS_SetFirstIndex(I1,1)
IS_SetLastIndex(I1,60)
IS_SetDigits(I1,2)
IS_SetType(I1,"png")
IS_SetExtension(I1,".png") 
IS_SetSourceFPS(I1,60) 
IS_SetTargetFPS(I1,25)
IS_SetWidth(I1,320)
IS_SetHeight(I1,240)

#declare I2 = I1;
IS_SetName(I2,"demob")
IS_SetLastIndex(I2,8)
IS_SetDigits(I2,1) 
IS_SetSourceFPS(I2,8) 

#declare I3 = I1;
IS_SetBlendedImages(I3,10) // More blurriness for I3. Default would be 2,4 (= SourceFPS/TargetFPS = 60/25). 
#declare I4 = I2;
IS_SetBlendedImages(I4,1.5)  // More blurriness for I4. Default would be 0.32 (=8/25). 
             
//
// Now set up the scene.
//
 
#macro SubTitle(Str)
   object {
   	Center_Object(text {ttf "cyrvetic.ttf", Str, .01, 0}, x)
   	scale 0.4*<.15,.15,1>
   	translate <0,-0.45,-1>
   	pigment {color White}
   	finish { ambient 0.7 }
   }
#end 
 
union {   
   object { IS_StandardBox(I1,clock) }
   object { SubTitle("60fps -> 25fps (default blending)") }
   scale 0.5
   translate <-0.25*4/3,0.25,0>
}

union {   
   object { IS_StandardBox(I2,clock) }
   object { SubTitle("8fps -> 25fps (default blending)") }
   scale 0.5
   translate <0.25*4/3,0.25,0>
}

union {   
   object { IS_StandardBox(I3,clock) }
   object { SubTitle("60fps -> 25fps (more blending)") }
   scale 0.5
   translate <-0.25*4/3,-0.25,0>
}

union {   
   object { IS_StandardBox(I4,clock) }
   object { SubTitle("8fps -> 25fps (more blending)") }
   scale 0.5
   translate <0.25*4/3,-0.25,0>
}
                                      
camera { IS_StandardCamera() }